==> subversion-1.24-sources.jar: hudson/scm/subversion/Messages.java <==
// CHECKSTYLE:OFF

package hudson.scm.subversion;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * No existing build. Scheduling a new one.
     * 
     */
    public static String SubversionSCM_pollChanges_noBuilds() {
        return holder.format("SubversionSCM.pollChanges.noBuilds");
    }

    /**
     * No existing build. Scheduling a new one.
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_noBuilds() {
        return new Localizable(holder, "SubversionSCM.pollChanges.noBuilds");
    }

    /**
     * One or more repository locations do not exist anymore for {0}, project will be disabled.
     * 
     */
    public static String SubversionSCM_pollChanges_locationsNoLongerExist(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.locationsNoLongerExist", arg1);
    }

    /**
     * One or more repository locations do not exist anymore for {0}, project will be disabled.
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_locationsNoLongerExist(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.locationsNoLongerExist", arg1);
    }

    /**
     * Workspace doesn''t contain {0}. Need a new build.
     * 
     */
    public static String SubversionSCM_pollChanges_locationNotInWorkspace(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.locationNotInWorkspace", arg1);
    }

    /**
     * Workspace doesn''t contain {0}. Need a new build.
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_locationNotInWorkspace(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.locationNotInWorkspace", arg1);
    }

    /**
     * Found exclusion revprop: {0}
     * 
     */
    public static String SubversionSCM_pollChanges_ignoredRevision_revprop(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.ignoredRevision.revprop", arg1);
    }

    /**
     * Found exclusion revprop: {0}
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_ignoredRevision_revprop(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.ignoredRevision.revprop", arg1);
    }

    /**
     *   (changed from {0})
     * 
     */
    public static String SubversionSCM_pollChanges_changedFrom(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.changedFrom", arg1);
    }

    /**
     *   (changed from {0})
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_changedFrom(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.changedFrom", arg1);
    }

    /**
     * Fetching ''{0}'' at {1} into ''{2}''
     * 
     */
    public static String SubversionUpdateEventHandler_FetchExternal(Object arg1, Object arg2, Object arg3) {
        return holder.format("SubversionUpdateEventHandler.FetchExternal", arg1, arg2, arg3);
    }

    /**
     * Fetching ''{0}'' at {1} into ''{2}''
     * 
     */
    public static Localizable _SubversionUpdateEventHandler_FetchExternal(Object arg1, Object arg2, Object arg3) {
        return new Localizable(holder, "SubversionUpdateEventHandler.FetchExternal", arg1, arg2, arg3);
    }

    /**
     * The remote location {0} does not support retrieving custom revision properties with svn log. Commits with revision properties will trigger builds.
     * 
     */
    public static String SubversionSCM_excludedRevprop_notSupported(Object arg1) {
        return holder.format("SubversionSCM.excludedRevprop.notSupported", arg1);
    }

    /**
     * The remote location {0} does not support retrieving custom revision properties with svn log. Commits with revision properties will trigger builds.
     * 
     */
    public static Localizable _SubversionSCM_excludedRevprop_notSupported(Object arg1) {
        return new Localizable(holder, "SubversionSCM.excludedRevprop.notSupported", arg1);
    }

    /**
     * {0} is at revision {1}
     * 
     */
    public static String SubversionSCM_pollChanges_remoteRevisionAt(Object arg1, Object arg2) {
        return holder.format("SubversionSCM.pollChanges.remoteRevisionAt", arg1, arg2);
    }

    /**
     * {0} is at revision {1}
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_remoteRevisionAt(Object arg1, Object arg2) {
        return new Localizable(holder, "SubversionSCM.pollChanges.remoteRevisionAt", arg1, arg2);
    }

    /**
     * Use ''svn update'' as much as possible
     * 
     */
    public static String UpdateUpdater_DisplayName() {
        return holder.format("UpdateUpdater.DisplayName");
    }

    /**
     * Use ''svn update'' as much as possible
     * 
     */
    public static Localizable _UpdateUpdater_DisplayName() {
        return new Localizable(holder, "UpdateUpdater.DisplayName");
    }

    /**
     * Tagged
     * 
     */
    public static String SubversionTagAction_Tooltip() {
        return holder.format("SubversionTagAction.Tooltip");
    }

    /**
     * Tagged
     * 
     */
    public static Localizable _SubversionTagAction_Tooltip() {
        return new Localizable(holder, "SubversionTagAction.Tooltip");
    }

    /**
     * Invalid URL syntax. See &lt;a href="http://svnbook.red-bean.com/en/1.2/svn-book.html#svn.basic.in-action.wc.tbl-1" target="_blank">this&lt;/a> for information about valid URLs.
     * 
     */
    public static String SubversionSCM_doCheckRemote_invalidUrl() {
        return holder.format("SubversionSCM.doCheckRemote.invalidUrl");
    }

    /**
     * Invalid URL syntax. See &lt;a href="http://svnbook.red-bean.com/en/1.2/svn-book.html#svn.basic.in-action.wc.tbl-1" target="_blank">this&lt;/a> for information about valid URLs.
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_invalidUrl() {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.invalidUrl");
    }

    /**
     * Subversion tags
     * 
     */
    public static String SubversionTagAction_DisplayName_HasTags() {
        return holder.format("SubversionTagAction.DisplayName.HasTags");
    }

    /**
     * Subversion tags
     * 
     */
    public static Localizable _SubversionTagAction_DisplayName_HasTags() {
        return new Localizable(holder, "SubversionTagAction.DisplayName.HasTags");
    }

    /**
     * Always check out a fresh copy
     * 
     */
    public static String CheckoutUpdater_DisplayName() {
        return holder.format("CheckoutUpdater.DisplayName");
    }

    /**
     * Always check out a fresh copy
     * 
     */
    public static Localizable _CheckoutUpdater_DisplayName() {
        return new Localizable(holder, "CheckoutUpdater.DisplayName");
    }

    /**
     * WARNING: clock of the subversion server appears to be out of sync. This can result in inconsistent check out behavior.
     * 
     */
    public static String SubversionSCM_ClockOutOfSync() {
        return holder.format("SubversionSCM.ClockOutOfSync");
    }

    /**
     * WARNING: clock of the subversion server appears to be out of sync. This can result in inconsistent check out behavior.
     * 
     */
    public static Localizable _SubversionSCM_ClockOutOfSync() {
        return new Localizable(holder, "SubversionSCM.ClockOutOfSync");
    }

    /**
     * Tag this build
     * 
     */
    public static String SubversionTagAction_DisplayName_HasNoTag() {
        return holder.format("SubversionTagAction.DisplayName.HasNoTag");
    }

    /**
     * Tag this build
     * 
     */
    public static Localizable _SubversionTagAction_DisplayName_HasNoTag() {
        return new Localizable(holder, "SubversionTagAction.DisplayName.HasNoTag");
    }

    /**
     * Found excluded author: {0}
     * 
     */
    public static String SubversionSCM_pollChanges_ignoredRevision_author(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.ignoredRevision.author", arg1);
    }

    /**
     * Found excluded author: {0}
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_ignoredRevision_author(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.ignoredRevision.author", arg1);
    }

    /**
     * Found no included paths
     * 
     */
    public static String SubversionSCM_pollChanges_ignoredRevision_noincpath() {
        return holder.format("SubversionSCM.pollChanges.ignoredRevision.noincpath");
    }

    /**
     * Found no included paths
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_ignoredRevision_noincpath() {
        return new Localizable(holder, "SubversionSCM.pollChanges.ignoredRevision.noincpath");
    }

    /**
     * Use 'svn update' as much as possible, with ''svn revert'' before update
     * 
     */
    public static String UpdateWithRevertUpdater_DisplayName() {
        return holder.format("UpdateWithRevertUpdater.DisplayName");
    }

    /**
     * Use 'svn update' as much as possible, with ''svn revert'' before update
     * 
     */
    public static Localizable _UpdateWithRevertUpdater_DisplayName() {
        return new Localizable(holder, "UpdateWithRevertUpdater.DisplayName");
    }

    /**
     * Subversion tag
     * 
     */
    public static String SubversionTagAction_DisplayName_HasATag() {
        return holder.format("SubversionTagAction.DisplayName.HasATag");
    }

    /**
     * Subversion tag
     * 
     */
    public static Localizable _SubversionTagAction_DisplayName_HasATag() {
        return new Localizable(holder, "SubversionTagAction.DisplayName.HasATag");
    }

    /**
     * Found only excluded paths: {0}
     * 
     */
    public static String SubversionSCM_pollChanges_ignoredRevision_path(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.ignoredRevision.path", arg1);
    }

    /**
     * Found only excluded paths: {0}
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_ignoredRevision_path(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.ignoredRevision.path", arg1);
    }

    /**
     * Emulate clean checkout by first deleting unversioned/ignored files, then ''svn update''
     * 
     */
    public static String UpdateWithCleanUpdater_DisplayName() {
        return holder.format("UpdateWithCleanUpdater.DisplayName");
    }

    /**
     * Emulate clean checkout by first deleting unversioned/ignored files, then ''svn update''
     * 
     */
    public static Localizable _UpdateWithCleanUpdater_DisplayName() {
        return new Localizable(holder, "UpdateWithCleanUpdater.DisplayName");
    }

    /**
     * (Maybe you need to &lt;a href="{0}" target="_blank">enter credential&lt;/a>?)
     * 
     */
    public static String SubversionSCM_doCheckRemote_exceptionMsg2(Object arg1) {
        return holder.format("SubversionSCM.doCheckRemote.exceptionMsg2", arg1);
    }

    /**
     * (Maybe you need to &lt;a href="{0}" target="_blank">enter credential&lt;/a>?)
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_exceptionMsg2(Object arg1) {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.exceptionMsg2", arg1);
    }

    /**
     * "{0}/{1}" doesn''t exist in the repository. Maybe you meant "{0}{2}"?
     * 
     */
    public static String SubversionSCM_doCheckRemote_badPathSuggest(Object arg1, Object arg2, Object arg3) {
        return holder.format("SubversionSCM.doCheckRemote.badPathSuggest", arg1, arg2, arg3);
    }

    /**
     * "{0}/{1}" doesn''t exist in the repository. Maybe you meant "{0}{2}"?
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_badPathSuggest(Object arg1, Object arg2, Object arg3) {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.badPathSuggest", arg1, arg2, arg3);
    }

    /**
     * Ignored revision {0}: {1}
     * 
     */
    public static String SubversionSCM_pollChanges_ignoredRevision(Object arg1, Object arg2) {
        return holder.format("SubversionSCM.pollChanges.ignoredRevision", arg1, arg2);
    }

    /**
     * Ignored revision {0}: {1}
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_ignoredRevision(Object arg1, Object arg2) {
        return new Localizable(holder, "SubversionSCM.pollChanges.ignoredRevision", arg1, arg2);
    }

    /**
     * Unable to access {0} : {1} &lt;a href="#" id="svnerrorlink" onclick="{2}">(show details)&lt;/a>
     * 
     */
    public static String SubversionSCM_doCheckRemote_exceptionMsg1(Object arg1, Object arg2, Object arg3) {
        return holder.format("SubversionSCM.doCheckRemote.exceptionMsg1", arg1, arg2, arg3);
    }

    /**
     * Unable to access {0} : {1} &lt;a href="#" id="svnerrorlink" onclick="{2}">(show details)&lt;/a>
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_exceptionMsg1(Object arg1, Object arg2, Object arg3) {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.exceptionMsg1", arg1, arg2, arg3);
    }

    /**
     * {0} doesn''t exist in the repository
     * 
     */
    public static String SubversionSCM_doCheckRemote_badPath(Object arg1) {
        return holder.format("SubversionSCM.doCheckRemote.badPath", arg1);
    }

    /**
     * {0} doesn''t exist in the repository
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_badPath(Object arg1) {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.badPath", arg1);
    }

    /**
     * Tag: {0}
     * 
     */
    public static String SubversionTagAction_Tooltip_OneTag(Object arg1) {
        return holder.format("SubversionTagAction.Tooltip.OneTag", arg1);
    }

    /**
     * Tag: {0}
     * 
     */
    public static Localizable _SubversionTagAction_Tooltip_OneTag(Object arg1) {
        return new Localizable(holder, "SubversionTagAction.Tooltip.OneTag", arg1);
    }

    /**
     * Invalid revision. Revision may either be a number or a &lt;a href="http://svnbook.red-bean.com/en/1.5/svn.tour.revs.specifiers.html" target="_blank">Revision Keyword or Date&lt;/a>.
     * 
     */
    public static String SubversionSCM_doCheckRemote_invalidRevision() {
        return holder.format("SubversionSCM.doCheckRemote.invalidRevision");
    }

    /**
     * Invalid revision. Revision may either be a number or a &lt;a href="http://svnbook.red-bean.com/en/1.5/svn.tour.revs.specifiers.html" target="_blank">Revision Keyword or Date&lt;/a>.
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_invalidRevision() {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.invalidRevision");
    }

    /**
     * Failed to check repository revision for {0}
     * 
     */
    public static String SubversionSCM_pollChanges_exception(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.exception", arg1);
    }

    /**
     * Failed to check repository revision for {0}
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_exception(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.exception", arg1);
    }

}

==> subversion-1.25-sources.jar: hudson/scm/subversion/Messages.java <==
// CHECKSTYLE:OFF

package hudson.scm.subversion;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * No existing build. Scheduling a new one.
     * 
     */
    public static String SubversionSCM_pollChanges_noBuilds() {
        return holder.format("SubversionSCM.pollChanges.noBuilds");
    }

    /**
     * No existing build. Scheduling a new one.
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_noBuilds() {
        return new Localizable(holder, "SubversionSCM.pollChanges.noBuilds");
    }

    /**
     * One or more repository locations do not exist anymore for {0}, project will be disabled.
     * 
     */
    public static String SubversionSCM_pollChanges_locationsNoLongerExist(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.locationsNoLongerExist", arg1);
    }

    /**
     * One or more repository locations do not exist anymore for {0}, project will be disabled.
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_locationsNoLongerExist(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.locationsNoLongerExist", arg1);
    }

    /**
     * Workspace doesn''t contain {0}. Need a new build.
     * 
     */
    public static String SubversionSCM_pollChanges_locationNotInWorkspace(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.locationNotInWorkspace", arg1);
    }

    /**
     * Workspace doesn''t contain {0}. Need a new build.
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_locationNotInWorkspace(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.locationNotInWorkspace", arg1);
    }

    /**
     * Found exclusion revprop: {0}
     * 
     */
    public static String SubversionSCM_pollChanges_ignoredRevision_revprop(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.ignoredRevision.revprop", arg1);
    }

    /**
     * Found exclusion revprop: {0}
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_ignoredRevision_revprop(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.ignoredRevision.revprop", arg1);
    }

    /**
     *   (changed from {0})
     * 
     */
    public static String SubversionSCM_pollChanges_changedFrom(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.changedFrom", arg1);
    }

    /**
     *   (changed from {0})
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_changedFrom(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.changedFrom", arg1);
    }

    /**
     * Fetching ''{0}'' at {1} into ''{2}''
     * 
     */
    public static String SubversionUpdateEventHandler_FetchExternal(Object arg1, Object arg2, Object arg3) {
        return holder.format("SubversionUpdateEventHandler.FetchExternal", arg1, arg2, arg3);
    }

    /**
     * Fetching ''{0}'' at {1} into ''{2}''
     * 
     */
    public static Localizable _SubversionUpdateEventHandler_FetchExternal(Object arg1, Object arg2, Object arg3) {
        return new Localizable(holder, "SubversionUpdateEventHandler.FetchExternal", arg1, arg2, arg3);
    }

    /**
     * The remote location {0} does not support retrieving custom revision properties with svn log. Commits with revision properties will trigger builds.
     * 
     */
    public static String SubversionSCM_excludedRevprop_notSupported(Object arg1) {
        return holder.format("SubversionSCM.excludedRevprop.notSupported", arg1);
    }

    /**
     * The remote location {0} does not support retrieving custom revision properties with svn log. Commits with revision properties will trigger builds.
     * 
     */
    public static Localizable _SubversionSCM_excludedRevprop_notSupported(Object arg1) {
        return new Localizable(holder, "SubversionSCM.excludedRevprop.notSupported", arg1);
    }

    /**
     * {0} is at revision {1}
     * 
     */
    public static String SubversionSCM_pollChanges_remoteRevisionAt(Object arg1, Object arg2) {
        return holder.format("SubversionSCM.pollChanges.remoteRevisionAt", arg1, arg2);
    }

    /**
     * {0} is at revision {1}
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_remoteRevisionAt(Object arg1, Object arg2) {
        return new Localizable(holder, "SubversionSCM.pollChanges.remoteRevisionAt", arg1, arg2);
    }

    /**
     * Use ''svn update'' as much as possible
     * 
     */
    public static String UpdateUpdater_DisplayName() {
        return holder.format("UpdateUpdater.DisplayName");
    }

    /**
     * Use ''svn update'' as much as possible
     * 
     */
    public static Localizable _UpdateUpdater_DisplayName() {
        return new Localizable(holder, "UpdateUpdater.DisplayName");
    }

    /**
     * Tagged
     * 
     */
    public static String SubversionTagAction_Tooltip() {
        return holder.format("SubversionTagAction.Tooltip");
    }

    /**
     * Tagged
     * 
     */
    public static Localizable _SubversionTagAction_Tooltip() {
        return new Localizable(holder, "SubversionTagAction.Tooltip");
    }

    /**
     * Invalid URL syntax. See &lt;a href="http://svnbook.red-bean.com/en/1.2/svn-book.html#svn.basic.in-action.wc.tbl-1" target="_blank">this&lt;/a> for information about valid URLs.
     * 
     */
    public static String SubversionSCM_doCheckRemote_invalidUrl() {
        return holder.format("SubversionSCM.doCheckRemote.invalidUrl");
    }

    /**
     * Invalid URL syntax. See &lt;a href="http://svnbook.red-bean.com/en/1.2/svn-book.html#svn.basic.in-action.wc.tbl-1" target="_blank">this&lt;/a> for information about valid URLs.
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_invalidUrl() {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.invalidUrl");
    }

    /**
     * Subversion tags
     * 
     */
    public static String SubversionTagAction_DisplayName_HasTags() {
        return holder.format("SubversionTagAction.DisplayName.HasTags");
    }

    /**
     * Subversion tags
     * 
     */
    public static Localizable _SubversionTagAction_DisplayName_HasTags() {
        return new Localizable(holder, "SubversionTagAction.DisplayName.HasTags");
    }

    /**
     * Always check out a fresh copy
     * 
     */
    public static String CheckoutUpdater_DisplayName() {
        return holder.format("CheckoutUpdater.DisplayName");
    }

    /**
     * Always check out a fresh copy
     * 
     */
    public static Localizable _CheckoutUpdater_DisplayName() {
        return new Localizable(holder, "CheckoutUpdater.DisplayName");
    }

    /**
     * WARNING: clock of the subversion server appears to be out of sync. This can result in inconsistent check out behavior.
     * 
     */
    public static String SubversionSCM_ClockOutOfSync() {
        return holder.format("SubversionSCM.ClockOutOfSync");
    }

    /**
     * WARNING: clock of the subversion server appears to be out of sync. This can result in inconsistent check out behavior.
     * 
     */
    public static Localizable _SubversionSCM_ClockOutOfSync() {
        return new Localizable(holder, "SubversionSCM.ClockOutOfSync");
    }

    /**
     * Tag this build
     * 
     */
    public static String SubversionTagAction_DisplayName_HasNoTag() {
        return holder.format("SubversionTagAction.DisplayName.HasNoTag");
    }

    /**
     * Tag this build
     * 
     */
    public static Localizable _SubversionTagAction_DisplayName_HasNoTag() {
        return new Localizable(holder, "SubversionTagAction.DisplayName.HasNoTag");
    }

    /**
     * Found excluded author: {0}
     * 
     */
    public static String SubversionSCM_pollChanges_ignoredRevision_author(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.ignoredRevision.author", arg1);
    }

    /**
     * Found excluded author: {0}
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_ignoredRevision_author(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.ignoredRevision.author", arg1);
    }

    /**
     * Found no included paths
     * 
     */
    public static String SubversionSCM_pollChanges_ignoredRevision_noincpath() {
        return holder.format("SubversionSCM.pollChanges.ignoredRevision.noincpath");
    }

    /**
     * Found no included paths
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_ignoredRevision_noincpath() {
        return new Localizable(holder, "SubversionSCM.pollChanges.ignoredRevision.noincpath");
    }

    /**
     * Use 'svn update' as much as possible, with ''svn revert'' before update
     * 
     */
    public static String UpdateWithRevertUpdater_DisplayName() {
        return holder.format("UpdateWithRevertUpdater.DisplayName");
    }

    /**
     * Use 'svn update' as much as possible, with ''svn revert'' before update
     * 
     */
    public static Localizable _UpdateWithRevertUpdater_DisplayName() {
        return new Localizable(holder, "UpdateWithRevertUpdater.DisplayName");
    }

    /**
     * Subversion tag
     * 
     */
    public static String SubversionTagAction_DisplayName_HasATag() {
        return holder.format("SubversionTagAction.DisplayName.HasATag");
    }

    /**
     * Subversion tag
     * 
     */
    public static Localizable _SubversionTagAction_DisplayName_HasATag() {
        return new Localizable(holder, "SubversionTagAction.DisplayName.HasATag");
    }

    /**
     * Found only excluded paths: {0}
     * 
     */
    public static String SubversionSCM_pollChanges_ignoredRevision_path(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.ignoredRevision.path", arg1);
    }

    /**
     * Found only excluded paths: {0}
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_ignoredRevision_path(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.ignoredRevision.path", arg1);
    }

    /**
     * Emulate clean checkout by first deleting unversioned/ignored files, then ''svn update''
     * 
     */
    public static String UpdateWithCleanUpdater_DisplayName() {
        return holder.format("UpdateWithCleanUpdater.DisplayName");
    }

    /**
     * Emulate clean checkout by first deleting unversioned/ignored files, then ''svn update''
     * 
     */
    public static Localizable _UpdateWithCleanUpdater_DisplayName() {
        return new Localizable(holder, "UpdateWithCleanUpdater.DisplayName");
    }

    /**
     * (Maybe you need to &lt;a href="{0}" target="_blank">enter credential&lt;/a>?)
     * 
     */
    public static String SubversionSCM_doCheckRemote_exceptionMsg2(Object arg1) {
        return holder.format("SubversionSCM.doCheckRemote.exceptionMsg2", arg1);
    }

    /**
     * (Maybe you need to &lt;a href="{0}" target="_blank">enter credential&lt;/a>?)
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_exceptionMsg2(Object arg1) {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.exceptionMsg2", arg1);
    }

    /**
     * "{0}/{1}" doesn''t exist in the repository. Maybe you meant "{0}{2}"?
     * 
     */
    public static String SubversionSCM_doCheckRemote_badPathSuggest(Object arg1, Object arg2, Object arg3) {
        return holder.format("SubversionSCM.doCheckRemote.badPathSuggest", arg1, arg2, arg3);
    }

    /**
     * "{0}/{1}" doesn''t exist in the repository. Maybe you meant "{0}{2}"?
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_badPathSuggest(Object arg1, Object arg2, Object arg3) {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.badPathSuggest", arg1, arg2, arg3);
    }

    /**
     * Ignored revision {0}: {1}
     * 
     */
    public static String SubversionSCM_pollChanges_ignoredRevision(Object arg1, Object arg2) {
        return holder.format("SubversionSCM.pollChanges.ignoredRevision", arg1, arg2);
    }

    /**
     * Ignored revision {0}: {1}
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_ignoredRevision(Object arg1, Object arg2) {
        return new Localizable(holder, "SubversionSCM.pollChanges.ignoredRevision", arg1, arg2);
    }

    /**
     * Unable to access {0} : {1} &lt;a href="#" id="svnerrorlink" onclick="{2}">(show details)&lt;/a>
     * 
     */
    public static String SubversionSCM_doCheckRemote_exceptionMsg1(Object arg1, Object arg2, Object arg3) {
        return holder.format("SubversionSCM.doCheckRemote.exceptionMsg1", arg1, arg2, arg3);
    }

    /**
     * Unable to access {0} : {1} &lt;a href="#" id="svnerrorlink" onclick="{2}">(show details)&lt;/a>
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_exceptionMsg1(Object arg1, Object arg2, Object arg3) {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.exceptionMsg1", arg1, arg2, arg3);
    }

    /**
     * Repository URL is required.
     * 
     */
    public static String SubversionSCM_doCheckRemote_required() {
        return holder.format("SubversionSCM.doCheckRemote.required");
    }

    /**
     * Repository URL is required.
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_required() {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.required");
    }

    /**
     * {0} doesn''t exist in the repository
     * 
     */
    public static String SubversionSCM_doCheckRemote_badPath(Object arg1) {
        return holder.format("SubversionSCM.doCheckRemote.badPath", arg1);
    }

    /**
     * {0} doesn''t exist in the repository
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_badPath(Object arg1) {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.badPath", arg1);
    }

    /**
     * Tag: {0}
     * 
     */
    public static String SubversionTagAction_Tooltip_OneTag(Object arg1) {
        return holder.format("SubversionTagAction.Tooltip.OneTag", arg1);
    }

    /**
     * Tag: {0}
     * 
     */
    public static Localizable _SubversionTagAction_Tooltip_OneTag(Object arg1) {
        return new Localizable(holder, "SubversionTagAction.Tooltip.OneTag", arg1);
    }

    /**
     * Invalid revision. Revision may either be a number or a &lt;a href="http://svnbook.red-bean.com/en/1.5/svn.tour.revs.specifiers.html" target="_blank">Revision Keyword or Date&lt;/a>.
     * 
     */
    public static String SubversionSCM_doCheckRemote_invalidRevision() {
        return holder.format("SubversionSCM.doCheckRemote.invalidRevision");
    }

    /**
     * Invalid revision. Revision may either be a number or a &lt;a href="http://svnbook.red-bean.com/en/1.5/svn.tour.revs.specifiers.html" target="_blank">Revision Keyword or Date&lt;/a>.
     * 
     */
    public static Localizable _SubversionSCM_doCheckRemote_invalidRevision() {
        return new Localizable(holder, "SubversionSCM.doCheckRemote.invalidRevision");
    }

    /**
     * Failed to check repository revision for {0}
     * 
     */
    public static String SubversionSCM_pollChanges_exception(Object arg1) {
        return holder.format("SubversionSCM.pollChanges.exception", arg1);
    }

    /**
     * Failed to check repository revision for {0}
     * 
     */
    public static Localizable _SubversionSCM_pollChanges_exception(Object arg1) {
        return new Localizable(holder, "SubversionSCM.pollChanges.exception", arg1);
    }

}
